// testweights.cpp
// Integration weights
// M. Bernreuther, 15.9.2000



#include "Numegration.h"

#include <iostream>
#include <cmath>
using namespace std;


int main(int argc, char *argv[ ])
{
	unsigned int i,j;

	cout << "Weights" << endl;
	Numegration::Points1D ip1(2,Numegration::Trapezoid);
	valarray<double> weights;
	double sum;

	cout << "Trapezoidal" << endl;
	for(i=2;i<=5;i++)
	{
		ip1.Setn(i);
		cout << i << ": " << endl;		
		weights=ip1.GetWeights();
		sum=0.;
		for(j=0;j<weights.size();j++)
		{
			cout << weights[j] << "\t";
			sum+=weights[j];
		}
		cout << endl << "\tsum: " << sum << endl;
		if(fabs(sum-2.)>1e-10) cout << "!!!!!!!!!! There must be something wrong: sum!=2. !!!!!!!!!!" << endl;
	}
	cout << endl;


	cout << "Simpson" << endl;
	ip1.Setn(3);
	ip1.SetRule(Numegration::Simpson);
	for(i=3;i<=7;i+=2)
	{
		ip1.Setn(i);
		cout << i << ": " << endl;		
		weights=ip1.GetWeights();
		sum=0.;
		for(j=0;j<weights.size();j++)
		{
			cout << weights[j] << "\t";
			sum+=weights[j];
		}
		cout << endl << "\tsum: " << sum << endl;
		if(fabs(sum-2.)>1e-10) cout << "!!!!!!!!!! There must be something wrong: sum!=2. !!!!!!!!!!" << endl;
	}
	cout << endl;

	cout << "Newton" << endl;
	ip1.Setn(4);
	ip1.SetRule(Numegration::Newton);
	for(i=4;i<=10;i+=3)
	{
		ip1.Setn(i);
		cout << i << ": " << endl;		
		weights=ip1.GetWeights();
		sum=0.;
		for(j=0;j<weights.size();j++)
		{
			cout << weights[j] << "\t";
			sum+=weights[j];
		}
		cout << endl << "\tsum: " << sum << endl;
		if(fabs(sum-2.)>1e-10) cout << "!!!!!!!!!! There must be something wrong: sum!=2. !!!!!!!!!!" << endl;
	}
	cout << endl;

	cout << "Gauss Legendre" << endl;
	ip1.SetParameters(2,Numegration::GaussLegendre);
	for(i=2;i<=24;i++)
	{
		ip1.Setn(i);
		cout << i << ": " << endl;		
		weights=ip1.GetWeights();
		sum=0.;
		for(j=0;j<weights.size();j++)
		{
			cout << weights[j] << "\t";
			sum+=weights[j];
		}
		cout << endl << "\tsum: " << sum << endl;
		if(fabs(sum-2.)>1e-10) cout << "!!!!!!!!!! There must be something wrong: sum!=2. !!!!!!!!!!" << endl;
	}
	cout << endl;

	cout << "Gauss Lobatto" << endl;
	ip1.SetParameters(2,Numegration::GaussLobatto);
	for(i=2;i<=10;i++)
	{
		ip1.Setn(i);
		cout << i << ": " << endl;		
		weights=ip1.GetWeights();
		sum=0.;
		for(j=0;j<weights.size();j++)
		{
			cout << weights[j] << "\t";
			sum+=weights[j];
		}
		cout << endl << "\tsum: " << sum << endl;
		if(fabs(sum-2.)>1e-10) cout << "!!!!!!!!!! There must be something wrong: sum!=2. !!!!!!!!!!" << endl;
	}
	return 0;
}
